<p align="center">
    <img alt="Lunes" src="docs/logo.png" width="100" />
</p>

# LunesPy

- Library for communication with nodes in mainnet or testnet of the lunes-blockchain network
  Allows the automation of **sending assets**, **issue end reissue tokens**, **lease** and **create new wallet**.

[![Test](https://github.com/lunes-platform/lunespy/actions/workflows/python-app.yml/badge.svg)](https://github.com/lunes-platform/lunespy/actions/workflows/python-app.yml)
[![License](https://img.shields.io/github/license/lunes-platform/lunespy?color=blueviolet)](LICENSE)
[![Stars](https://img.shields.io/github/stars/lunes-platform/lunespy?color=blueviolet)](https://github.com/lunes-platform/lunespy/stargazers)

[![CommitActivity](https://img.shields.io/github/commit-activity/m/lunes-platform/lunespy?color=blueviolet)](https://github.com/lunes-platform/lunespy/pulse)
[![Forks](https://img.shields.io/github/forks/lunes-platform/lunespy?color=blueviolet)](https://github.com/lunes-platform/lunespy/network/members)
[![Contributors](https://flat.badgen.net/github/contributors/lunes-platform/lunespy?color=purple)](https://github.com/lunes-platform/lunespy/graphs/contributors)
![ClosedIssue](https://flat.badgen.net/github/closed-issues/lunes-platform/lunespy?color=red)
[![Branches](https://badgen.net/github/branches/lunes-platform/lunespy?color=blueviolet)](https://github.com/lunes-platform/lunespy/branches)
[![Watchers](https://img.shields.io/github/watchers/lunes-platform/lunespy.svg?color=blueviolet)](https://github.com/lunes-platform/lunespy/watchers)
[![Followers](https://img.shields.io/github/followers/lunes-platform.svg?style=social&label=Follow&maxAge=2592000?color=blueviolet)](https://github.com/lunes-platform?tab=followers)
[![Website](https://img.shields.io/website?url=https%3A%2F%2Flunes.io%2F)](https://lunes.io)
![PullRequest](https://img.shields.io/github/issues-pr/lunes-platform/lunespy?color=blueviolet)
![PullRequestClosed](https://img.shields.io/github/issues-pr-closed/lunes-platform/lunespy?color=blueviolet)

<br><br>
<a href="https://twitter.com/LunesPlatform" target="_blank">
<img alt="Twitter: Lunes Platform" src="https://badgen.net/twitter/follow/lunesplatform?icon=twitter&label=follow @LunesPlatform&color=blue" />
</a>  
 <a href="https://t.me/LunesPlatformPT" target="_blank">
<img alt="Telegram" src="https://badgen.net/badge/icon/Lunes%20Platform?icon=telegram&label=Telegram&color=blue"/>
</a>

## Documentation

The `lunespy` documentations is hosted at [Telescope](https://blockchain.lunes.io/telescope/)

## Changelog

The changelog process for this project is described [here](CHANGELOG.md).

## Contributing

`lunespy` is still under development. Contributions are always welcome! Please follow the [Developers Guide](CONTRIBUTING.md) if you want to help.

Thanks to the following people who have contributed to this project:

- [olivmath](https://github.com/olivmath)
- [marcoslkz](https://github.com/marcoslkz)
- [VanJustin](https://github.com/VanJustin)
- [xonfps](https://github.com/xonfps)

## Contact

If you want to contact me you can reach me at <development@lunes.io>.

## License

[Apache License Version 2.0](https://github.com/lunes-platform/lunespy/blob/main/LICENSE).
